httpp/async
Values
pub fn send(
req: request.Request(bytes_tree.BytesTree),
) -> Result(
process.Subject(response.Response(BitArray)),
hackney.Error,
)
Send a request and receive a subject which you can receive to get the response
pub fn send(
req: request.Request(bytes_tree.BytesTree),
) -> Result(
process.Subject(response.Response(BitArray)),
hackney.Error,
)
Send a request and receive a subject which you can receive to get the response